"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Bean = exports.getValidationModel = exports.Resource = exports.Property = exports.Validate = exports.Param = exports.Component = exports.Service = exports.RequestMapping = exports.PutMapping = exports.PostMapping = exports.PatchMapping = exports.GetMapping = exports.DeleteMapping = exports.Controller = void 0;
require("reflect-metadata");
const BeanFactory_1 = require("../BeanFactory");
const HashMap_1 = require("../HashMap");
const BeanFactoryQueue_1 = require("../queue/BeanFactoryQueue");
/**
 * 存储
 * value set is {key:Array<ValidationProperty>}
 */
const validationModel = new HashMap_1.Map();
/**
 *  // 获取成员类型
 let type = Reflect.getMetadata('design:type', target, propertyName)
 // 获取成员参数类型
 let paramtypes = Reflect.getMetadata('design:paramtypes', target, propertyName)
 // 获取成员返回类型
 let returntype = Reflect.getMetadata('design:returntype', target, propertyName)
 */
/**
 *  标识是一个controller层
 * @param value 值
 * @param annotationModel
 * @constructor
 */
function Controller(value, annotationModel = { group: "api" }) {
    return function (target) {
        let l = BeanFactory_1.BeanFactory.createModel(target).initClass(target, new BeanFactory_1.BeanData(value, BeanFactory_1.BeanFactory.getName(target).name, BeanFactory_1.HttpMethod.GET, annotationModel.group).setUrl(annotationModel.url)).initValidateModel();
        BeanFactoryQueue_1.BeanFactoryQueue.consumeQueue(target, l.class);
    };
}
exports.Controller = Controller;
/**
 * 删除请求
 * @param value 删除的路径
 * @constructor
 */
function DeleteMapping(value, annotationMapping = {
    group: "api",
    dataType: BeanFactory_1.DataType.JSON
}) {
    return function (target, propertyKey, descriptor) {
        BeanFactory_1.BeanFactory.createModel(target).initMethod(target, propertyKey, new BeanFactory_1.Path(value, propertyKey, BeanFactory_1.HttpMethod.DELETE, annotationMapping.group, annotationMapping.dataType));
    };
}
exports.DeleteMapping = DeleteMapping;
/**
 * get请求
 * @param value 请求路径
 * @param annotationMapping
 * @constructor
 */
function GetMapping(value, annotationMapping = {
    group: "api",
    dataType: BeanFactory_1.DataType.DEFAULT
}) {
    return function (target, propertyKey, descriptor) {
        BeanFactory_1.BeanFactory.createModel(target).initMethod(target, propertyKey, new BeanFactory_1.Path(value, propertyKey, BeanFactory_1.HttpMethod.GET, annotationMapping.group, annotationMapping.dataType));
    };
}
exports.GetMapping = GetMapping;
/**
 *  Patch请求
 * @param value 请求路径
 * @param annotationMapping
 * @constructor
 */
function PatchMapping(value, annotationMapping = {
    group: "api",
    dataType: BeanFactory_1.DataType.DEFAULT
}) {
    return function (target, propertyKey, descriptor) {
        BeanFactory_1.BeanFactory.createModel(target).initMethod(target, propertyKey, new BeanFactory_1.Path(value, propertyKey, BeanFactory_1.HttpMethod.PATCH, annotationMapping.group, annotationMapping.dataType));
    };
}
exports.PatchMapping = PatchMapping;
/**
 *  Post请求
 * @param value 请求路径
 * @constructor
 */
function PostMapping(value, annotationMapping = {
    group: "api",
    dataType: BeanFactory_1.DataType.JSON
}) {
    return function (target, propertyKey, descriptor) {
        BeanFactory_1.BeanFactory.createModel(target).initMethod(target, propertyKey, new BeanFactory_1.Path(value, propertyKey, BeanFactory_1.HttpMethod.POST, annotationMapping.group, annotationMapping.dataType));
    };
}
exports.PostMapping = PostMapping;
/**
 *  Put请求
 * @param value 请求路径
 * @constructor
 */
function PutMapping(value, annotationMapping = {
    group: "api",
    dataType: BeanFactory_1.DataType.JSON
}) {
    return function (target, propertyKey, descriptor) {
        BeanFactory_1.BeanFactory.createModel(target).initMethod(target, propertyKey, new BeanFactory_1.Path(value, propertyKey, BeanFactory_1.HttpMethod.PUT, annotationMapping.group, annotationMapping.dataType));
    };
}
exports.PutMapping = PutMapping;
/**
 * RequestMapping请求
 * @param value 请求路径
 * @param group api分组
 * @constructor
 */
function RequestMapping(value, annotationMapping = {
    group: "api",
    method: BeanFactory_1.HttpMethod.GET,
    dataType: BeanFactory_1.DataType.DEFAULT
}) {
    return function (target, propertyKey, descriptor) {
        BeanFactory_1.BeanFactory.createModel(target).initMethod(target, propertyKey, new BeanFactory_1.Path(value, propertyKey, annotationMapping.method, annotationMapping.group, annotationMapping.dataType));
    };
}
exports.RequestMapping = RequestMapping;
/**
 * Service标识
 * @param value service名称  默认当前类名称
 * @constructor
 */
function Service(value) {
    return function (target) {
        BeanFactoryQueue_1.BeanFactoryQueue.consumeQueue(target, BeanFactory_1.BeanFactory.create(target));
    };
}
exports.Service = Service;
/**
 * Component标识
 * @param value service名称  默认当前类名称
 * @constructor
 */
function Component(value) {
    return function (target) {
        BeanFactoryQueue_1.BeanFactoryQueue.consumeQueue(target, BeanFactory_1.BeanFactory.create(target));
    };
}
exports.Component = Component;
/**
 * 参数注解
 * @param message
 * @param property 验证属性
 * @constructor
 */
function Param(message, property) {
    return function (target, propertyKey, parameterIndex) {
        let key = BeanFactory_1.BeanFactory.getName(target);
        let obj = {};
        if (validationModel.containsKey(key)) {
            obj = validationModel.get(key);
            // @ts-ignore
            obj[propertyKey] = property;
        }
        else {
            // @ts-ignore
            obj[propertyKey] = property;
            validationModel.put(key, obj);
        }
    };
}
exports.Param = Param;
/**
 * 参数注解
 * @param message
 * @param property 验证属性
 * @constructor
 */
function Validate(message, property) {
    return function (target, propertyKey, parameterIndex) {
        let key = BeanFactory_1.BeanFactory.getName(target);
        let obj = {};
        console.log(key);
    };
}
exports.Validate = Validate;
/**
 * 属性注解
 * @param message
 * @param property 验证相关
 * @constructor
 */
function Property(message, property = []) {
    /**
     * @param target 类
     * @package attr 属性名称
     */
    return function (target, attr) {
        let key = BeanFactory_1.BeanFactory.getName(target);
        let obj = {};
        if (validationModel.containsKey(key)) {
            obj = validationModel.get(key);
            // @ts-ignore
            obj[attr] = property;
        }
        else {
            // @ts-ignore
            obj[attr] = property;
            validationModel.put(key, obj);
        }
    };
}
exports.Property = Property;
/**
 * 依赖注入
 * @param value
 * @constructor
 */
function Resource(value) {
    return function (target, propertyName) {
        // 获取成员类型
        let type = Reflect.getMetadata('design:type', target, propertyName);
        BeanFactoryQueue_1.BeanFactoryQueue.addQueue({
            annotationBean: null,
            target: target,
            type: type,
            propertyKey: propertyName,
            descriptor: null
        });
    };
}
exports.Resource = Resource;
/**
 * 获取验证model的属性
 * @param fn
 */
function getValidationModel(fn) {
    return validationModel.get(fn);
}
exports.getValidationModel = getValidationModel;
/**
 * RequestMapping请求
 * @constructor
 * @param annotationBean
 */
function Bean(annotationBean = {}) {
    return function (target, propertyKey, descriptor) {
        BeanFactoryQueue_1.BeanFactoryQueue.consumeQueue(target, BeanFactory_1.BeanFactory.createModel(target[propertyKey](), annotationBean).class);
    };
}
exports.Bean = Bean;
