import { AxiosPromise } from "csap-axios";
import { Id, Page } from "../param/Page";
import BaseDao from "../dao/BaseDao";
import { ResponseManagerModel, Result } from "../model/Result";
import { Request } from "../model/Request";
import { DefaultHttpRequest } from "../service/DefaultHttpRequest";
/**
 * 基本接口定义
 * T 表单类型
 * S 筛选类型
 * R 列表返回类型
 * ID 主键
 */
export declare abstract class BaseService<T, S extends Page, R, ID> implements BaseDao<T, S, R, ID> {
    httpRequest: DefaultHttpRequest;
    /**
     * 获取请求对象
     */
    getHttpRequest(): DefaultHttpRequest;
    /**
     * 多条删除<根据主键删除>
     * @param ids
     */
    deletes(ids: Request<Array<ID>>): AxiosPromise<Result<number>>;
    /**
     * 单条删除<根据主键删除>
     * @param id
     */
    delete(id: Request<Id<ID>>): AxiosPromise<Result<boolean>>;
    /**
     * 根据主键查询
     * @param id
     */
    findById(id: Request<Id<ID>>): AxiosPromise<Result<R>>;
    /**
     * 添加
     * @param data
     */
    insert(data: Request<T>): AxiosPromise<Result<boolean>>;
    /**
     * 不分页查询
     * @param data
     */
    query(data: Request<S>): AxiosPromise<Result<Array<R>>>;
    /**
     * 分页查询
     * @param data
     */
    queryListPage(data: Request<S>): AxiosPromise<Result<Array<R>>>;
    /**
     * 返回总条数的分页查询
     * @param data
     */
    queryManagerListPage(data: Request<S>): AxiosPromise<Result<ResponseManagerModel<R>>>;
    /**
     * 修改
     * @param data 为request<Model> 对象
     */
    update(data: Request<T>): AxiosPromise<Result<boolean>>;
}
